; random-seed layout article : -464431851

breed [consumers consumer]
breed [goods good]
undirected-link-breed [purchase-links purchase-link]
undirected-link-breed [consumer-links consumer-link]
extensions [ nw matrix ]

globals [
  clustering-coefficient
  average-path-length
]

consumers-own [
  random-value     ;; a 3-dimension vector, each dimension has a random value between 0 and 1. It is used to initialise consumers according to proportion-intention-t0.
  intention ;; The set of intentions to purchase each of the characteristics, the result of a dynamic process (Endogenous-binary vector)
  purchase ;; The set of characteristics a consumer purchases at a given time-step, with or without intention (Endogenous-binary vector)
  purchase-t-1 ;; Purchase at (t-1)
  budget ;; Each consumer is endowed randomly with an individual budget, reacquired at each timestep (Exogenous-continuous)
  adoption ;; a binary vector counting indicating whether an consumer's purchase was done with intention or not
  new-intention ;; an auxiliary variable when dropping characteristics due to expensiveness
  candidates ;; the set of goods that contain the characteristics the consumer seeks
  candidate ;; a good chosen amongst the candidates
  my-clustering-coefficient ;; the current clustering coefficient of this node
  distance-from-other-consumers ;; a variable used in the construction of the network
]

goods-own [
  characteristics ;; Goods can have or not each one of the characteristics that are parametrised in the model. (Exogenous-binary vector)
  price  ;; the price of the particular good, a function of the number of characteristics it contains
  number-buyers ;; how many agents choose to create a purchase-link with the good
  number-characteristics ;; how many ones there are in the vector of characteristics
]


to setup
  ca
  ask patches [set pcolor white]
  set-default-shape consumers "person"
  set-default-shape goods "box"
  setup-generator
  setup-consumers
  setup-goods
  set clustering-coefficient find-clustering-coefficient
  set average-path-length find-average-path-length
  reset-ticks
end

to setup-generator
  if new-seed? [
    set seed-for-random new-seed
  ]
  random-seed seed-for-random
end

to setup-consumers
  clear-turtles
  create-consumers n-consumers [
    init-consumer self
  ]
  layout-circle (sort consumers) max-pxcor - 1
  if network-type = "random" [
    ask consumers [(create-consumer-links-with n-of (random ( 2 * (random-consumer-links + 1))) other consumers) ]
  ]
  if network-type = "small world" [
  wire-lattice
  ]
  ask consumer-links [set color green]
  ask consumers [set size 0.888
    ifelse (who mod 2 = 0)
      [forward 0.5]
    [forward -0.5]]
end

;; The following three procedures are taken from the Small World model from the NetLogo Library. Wilensky, U. (2015). NetLogo Small Worlds model. http://ccl.northwestern.edu/netlogo/models/SmallWorlds. Center for Connected Learning and Computer-Based Modeling, Northwestern University, Evanston, IL.
to wire-lattice
  ; iterate over the turtles
  let n 0
  while [ n < count consumers ] [
    ; make edges with the next two neighbors
    ; this makes a lattice with average degree of 4
    make-edge consumer n
              consumer ((n + 1) mod count consumers)
              ; "default"
    ; Make the neighbor's neighbor links curved
    make-edge consumer n
              consumer ((n + 2) mod count consumers)
              ; "curve"
    set n n + 1
  ]
  if random-links? [
  ask consumers [(create-consumer-links-with n-of (random ( 2 * (random-consumer-links))) other consumers) ]
  ]
end

to rewire-me ; consumer procedure
  ; node-A remains the same
  let node-A end1
  ; as long as A is not connected to everybody
  if [ count consumer-link-neighbors ] of end1 < (count consumers - 1) [
    ; find a node distinct from A and not already a neighbor of "A"
    let node-B one-of consumers with [ (self != node-A) and (not consumer-link-neighbor? node-A) ]
    ; wire the new edge
    ask node-A [ create-consumer-link-with node-B ]
    die ; remove the old edge
  ]
end

to make-edge [ node-A node-B ] ; the-shape ]
  ask node-A [
    create-consumer-link-with node-B  [
      ; set shape the-shape
      ; set rewired? false
    ]
  ]
end

to init-consumer [p]
  ask p [
    set random-value n-values n-dimensions [random-float 1]
    set intention n-values n-dimensions [0]
    let i 0
    repeat n-dimensions [
      if (item i random-value) < proportion-intention-t0 [set intention replace-item i intention 1]
      set i (i + 1)]
    set purchase n-values n-dimensions [0]
    set adoption n-values n-dimensions [0]

    set budget (1 + (random-float 1))
    ; set color scale-color red budget 2 1
    set color black
]
end

to setup-goods
  create-goods (2 ^ n-dimensions)
  let i 0
  repeat (2 ^ n-dimensions) [
    ask good (n-consumers + i) [
      set characteristics matrix:get-row matrix-characteristics  i
      random-seed seed-for-random
      setxy random-xcor random-ycor
      set number-characteristics (sum characteristics)
      set price 1
      let j 1
      set price price + number-characteristics * (price-premium / 100)
      set color brown
    ]
    set i (i + 1)
  ]
  ask goods [(setxy random-xcor random-ycor) ]
end


to-report matrix-characteristics
  if n-dimensions = 1 [ let full-matrix matrix:from-row-list [ [0] [1] ]
    report full-matrix ]
  if n-dimensions = 2 [ let full-matrix matrix:from-row-list [ [0 0] [1 0] [0 1] [1 1] ]
    report full-matrix ]
  if n-dimensions = 3 [ let full-matrix matrix:from-row-list [ [0 0 0] [1 0 0] [0 1 0] [0 0 1] [1 1 0] [1 0 1] [0 1 1] [1 1 1] ]
    report full-matrix ]
  if n-dimensions = 4 [ let full-matrix matrix:from-row-list [ [0 0 0 0] [1 0 0 0] [0 1 0 0] [0 0 1 0] [0 0 0 1] [1 1 0 0] [1 0 1 0] [1 0 0 1] [0 1 1 0] [ 0 1 0 1] [ 0 0 1 1] [1 1 1 0] [1 0 1 1] [1 1 0 1] [0 1 1 1] [1 1 1 1] ]
    report full-matrix ]
end


to go
  update-intention
  buy
  if ( (max [number-buyers] of goods) = n-consumers ) [stop]
  tick
  if ticks = time-limit [stop]
  set clustering-coefficient find-clustering-coefficient
end


to update-intention
  ask consumers [
    let my-network-adoption adoption-network
    let i 0
    repeat n-dimensions [
      if (count my-network-of-influence > 0)
      and ( ( (item i my-network-adoption) / (count my-network-of-influence) ) > influence-threshold )
      and (random-float 1 < probability-influence)
      and ((random 10) < ticks) [
      set intention replace-item i intention 1 ]
    set i (i + 1) ]
  ]
end

to-report my-network-of-influence
  nw:set-context consumers consumer-links
  let nearby nw:turtles-in-radius degree-influence ; how far the nodes that can influence an agent can be
  set nearby nearby with [self != myself]
  report nearby
end

to-report adoption-network ;; number of consumer's in a consumer's network who purchase with intention.
  let update-network-adoption n-values n-dimensions [0]
  if (count my-network-of-influence) > 0 [
    let j 0
    let matrix-neighbors-adoption (matrix:from-row-list ([adoption] of my-network-of-influence))
    repeat n-dimensions [
      set update-network-adoption replace-item j update-network-adoption (sum matrix:get-column matrix-neighbors-adoption j)
      set j (j + 1) ]
  ]
  report update-network-adoption
end


to-report match-ones [source target]
  (foreach source target [[?s ?t] ->
    if ?s != 1 and ?t = 1 [ report false ]
  ])
  report true
end


to buy
  ask purchase-links [ die ]
  ask consumers [
    set purchase-t-1 purchase
    set new-intention intention
    ifelse budget < [price] of good (n-consumers + 1) [
      create-purchase-link-with good (n-consumers) ]
    [ buy1 ]
  ]
  ask goods [
    set number-buyers count link-neighbors
  ]
  ask purchase-links [set color red]
end

to buy1
  ifelse (reduce + new-intention) = 0

  [set candidate one-of goods with [price <= [budget] of myself]
    create-purchase-link-with candidate
    update-adoption]

  [set candidates goods with [(match-ones characteristics [new-intention] of myself) and (price <= [budget] of myself)]
    let n-candidates count candidates
    ifelse n-candidates > 0
    [set candidate one-of candidates
      create-purchase-link-with candidate
      update-adoption]

    [let my-search (map * new-intention random-value)
      let low-preference position (min (filter [ i -> i != 0] my-search)) my-search
      set new-intention replace-item low-preference new-intention 0
      buy1]
  ]
end


to update-adoption
  let k 0
  repeat n-dimensions [
    if (item k purchase != item k [characteristics] of candidate) [
      set purchase replace-item k purchase item k [characteristics] of candidate
        if (item k intention = 1 and item k purchase = 1) [
        set adoption replace-item k adoption 1 ]
    ]
    set k (k + 1)
  ]
end


;;;INDICATORS

to-report intention1D
  if n-dimensions = 1 [ let number  (precision (100 * ((count consumers with [ (item 0 intention = 1) and (budget > [price] of good (n-consumers + 1) ) ]) / n-consumers)) 2)
    report number ]
  if n-dimensions = 2 [ let number  (precision (100 * ((count consumers with [ ((item 0 intention) + (item 1 intention) >= 1) and (budget > [price] of good (n-consumers + 1) ) ]) / n-consumers)) 2)
    report number ]
  if n-dimensions = 3 [ let number  (precision (100 * ((count consumers with [ ((item 0 intention) + (item 1 intention) + (item 2 intention) >= 1)  and (budget > [price] of good (n-consumers + 1) ) ]) / n-consumers)) 2)
    report number ]
    if n-dimensions = 4 [ let number  (precision (100 * ((count consumers with [ ((item 0 intention) + (item 1 intention) + (item 2 intention) + (item 3 intention) >= 1)  and (budget > [price] of good (n-consumers + 1) ) ]) / n-consumers)) 2)
    report number ]
end

to-report intention2D
  if n-dimensions = 1 [let number ""
    report number ]
  if n-dimensions = 2 [ let number  (precision (100 * ((count consumers with [ ((item 0 intention) + (item 1 intention) >= 2) and (budget > [price] of good (n-consumers + 3) ) ]) / n-consumers)) 2)
    report number ]
  if n-dimensions = 3 [ let number  (precision (100 * ((count consumers with [ ((item 0 intention) + (item 1 intention) + (item 2 intention) >= 2) and (budget > [price] of good (n-consumers + 3) ) ]) / n-consumers)) 2)
    report number ]
    if n-dimensions = 4 [ let number  (precision (100 * ((count consumers with [ ((item 0 intention) + (item 1 intention) + (item 2 intention) + (item 3 intention) >= 2) and (budget > [price] of good (n-consumers + 3) ) ]) / n-consumers)) 2)
    report number ]

end

to-report intention3D
  if n-dimensions = 1 [let number ""
    report number ]
  if n-dimensions = 2 [let number ""
    report number ]
  if n-dimensions = 3 [ let number  (precision (100 * ((count consumers with [ ((item 0 intention) + (item 1 intention) + (item 2 intention) >= 3) and (budget > [price] of good (n-consumers + 7) ) ]) / n-consumers)) 2)
    report number ]
    if n-dimensions = 4 [ let number  (precision (100 * ((count consumers with [ ((item 0 intention) + (item 1 intention) + (item 2 intention) + (item 3 intention) >= 3) and (budget > [price] of good (n-consumers + 7) ) ]) / n-consumers)) 2)
    report number ]
end


to-report intention4D
  if n-dimensions = 1 [let number ""
    report number ]
  if n-dimensions = 2 [let number ""
    report number ]
  if n-dimensions = 3 [ let number ""
    report number ]
  if n-dimensions = 4 [ let number  (precision (100 * ((count consumers with [ ((item 0 intention) + (item 1 intention) + (item 2 intention) + (item 3 intention) >= 4) and (budget > [price] of good (n-consumers + 15) ) ]) / n-consumers)) 2)
    report number ]
end
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
to-report adoption1D
  if n-dimensions = 1 [ let number  (precision (100 * ((count consumers with [ (item 0 adoption = 1) and (budget > [price] of good (n-consumers + 1) ) ]) / n-consumers)) 2)
    report number ]
  if n-dimensions = 2 [ let number  (precision (100 * ((count consumers with [ ((item 0 adoption) + (item 1 adoption) >= 1) and (budget > [price] of good (n-consumers + 1) ) ]) / n-consumers)) 2)
    report number ]
  if n-dimensions = 3 [ let number  (precision (100 * ((count consumers with [ ((item 0 adoption) + (item 1 adoption) + (item 2 adoption) >= 1)  and (budget > [price] of good (n-consumers + 1) ) ]) / n-consumers)) 2)
    report number ]
    if n-dimensions = 4 [ let number  (precision (100 * ((count consumers with [ ((item 0 adoption) + (item 1 adoption) + (item 2 adoption) + (item 3 adoption) >= 1)  and (budget > [price] of good (n-consumers + 1) ) ]) / n-consumers)) 2)
    report number ]
end

to-report adoption2D
  if n-dimensions = 1 [let number ""
    report number ]
  if n-dimensions = 2 [ let number  (precision (100 * ((count consumers with [ ((item 0 adoption) + (item 1 adoption) >= 2) and (budget > [price] of good (n-consumers + 3) ) ]) / n-consumers)) 2)
    report number ]
  if n-dimensions = 3 [ let number  (precision (100 * ((count consumers with [ ((item 0 adoption) + (item 1 adoption) + (item 2 adoption) >= 2) and (budget > [price] of good (n-consumers + 3) ) ]) / n-consumers)) 2)
    report number ]
    if n-dimensions = 4 [ let number  (precision (100 * ((count consumers with [ ((item 0 adoption) + (item 1 adoption) + (item 2 adoption) + (item 3 adoption) >= 2) and (budget > [price] of good (n-consumers + 3) ) ]) / n-consumers)) 2)
    report number ]

end

to-report adoption3D
  if n-dimensions = 1 [let number ""
    report number ]
  if n-dimensions = 2 [let number ""
    report number ]
  if n-dimensions = 3 [ let number  (precision (100 * ((count consumers with [ ((item 0 adoption) + (item 1 adoption) + (item 2 adoption) >= 3) and (budget > [price] of good (n-consumers + 7) ) ]) / n-consumers)) 2)
    report number ]
    if n-dimensions = 4 [ let number  (precision (100 * ((count consumers with [ ((item 0 adoption) + (item 1 adoption) + (item 2 adoption) + (item 3 adoption) >= 3) and (budget > [price] of good (n-consumers + 7) ) ]) / n-consumers)) 2)
    report number ]
end


to-report adoption4D
  if n-dimensions = 1 [let number ""
    report number ]
  if n-dimensions = 2 [let number ""
    report number ]
  if n-dimensions = 3 [ let number ""
    report number ]
  if n-dimensions = 4 [ let number  (precision (100 * ((count consumers with [ ((item 0 adoption) + (item 1 adoption) + (item 2 adoption) + (item 3 adoption) >= 4) and (budget > [price] of good (n-consumers + 15) ) ]) / n-consumers)) 2)
    report number ]
end



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
to-report purchase1D
  if n-dimensions = 1 [ let number  (precision (100 * ((count consumers with [ item 0 purchase = 1 ]) / n-consumers)) 2)
    report number ]
  if n-dimensions = 2 [ let number  (precision (100 * ((count consumers with [ (item 0 purchase) + (item 1 purchase) >= 1 ]) / n-consumers)) 2)
    report number ]
  if n-dimensions = 3 [ let number  (precision (100 * ((count consumers with [ (item 0 purchase) + (item 1 purchase) + (item 2 purchase) >= 1 ]) / n-consumers)) 2)
    report number ]
  if n-dimensions = 4 [ let number  (precision (100 * ((count consumers with [ (item 0 purchase) + (item 1 purchase) + (item 2 purchase) + (item 3 purchase) >= 1 ]) / n-consumers)) 2)
    report number ]
end

to-report purchase2D
  if n-dimensions = 1 [let number ""
    report number ]
  if n-dimensions = 2 [ let number  (precision (100 * ((count consumers with [ (item 0 purchase) + (item 1 purchase) >= 2 ]) / n-consumers)) 2)
    report number ]
  if n-dimensions = 3 [ let number  (precision (100 * ((count consumers with [ (item 0 purchase) + (item 1 purchase) + (item 2 purchase) >= 2 ]) / n-consumers)) 2)
    report number ]
  if n-dimensions = 4 [ let number  (precision (100 * ((count consumers with [ (item 0 purchase) + (item 1 purchase) + (item 2 purchase) + (item 3 purchase) >= 2 ]) / n-consumers)) 2)
    report number ]
end


to-report purchase3D
  if n-dimensions = 1 [let number ""
    report number ]
  if n-dimensions = 2 [let number ""
    report number ]
  if n-dimensions = 3 [ let number  (precision (100 * ((count consumers with [ (item 0 purchase) + (item 1 purchase) + (item 2 purchase) >= 3 ]) / n-consumers)) 2)
    report number ]
  if n-dimensions = 4 [ let number  (precision (100 * ((count consumers with [ (item 0 purchase) + (item 1 purchase) + (item 2 purchase) + (item 3 purchase) >= 3 ]) / n-consumers)) 2)
    report number ]
end


to-report purchase4D
  if n-dimensions = 1 [let number ""
    report number ]
  if n-dimensions = 2 [let number ""
    report number ]
  if n-dimensions = 3 [ let number ""
    report number ]
  if n-dimensions = 4 [ let number  (precision (100 * ((count consumers with [ (item 0 purchase) + (item 1 purchase) + (item 2 purchase) + (item 3 purchase) >= 4 ]) / n-consumers)) 2)
    report number ]
end

;;;;;;;;;;;;;;;;
;; Clustering and path-length computations ;;
;;;;;;;;;;;;;;;;

to-report find-clustering-coefficient

  let cc 99999 ; this is an arbitrary choice for a large number

  ifelse all? consumers [ count consumer-link-neighbors <= 1 ] [
    ; it is undefined
    ; what should this be?
    set cc 0
  ][
    let total 0
    ask consumers with [ count consumer-link-neighbors <= 1 ] [ set my-clustering-coefficient "undefined" ]
    ask consumers with [ count consumer-link-neighbors > 1 ] [
      let hood consumer-link-neighbors
      set my-clustering-coefficient (2 * count consumer-links with [ in-neighborhood? hood ] /
                                         ((count hood) * (count hood - 1)) )
      ; find the sum for the value at turtles
      set total total + my-clustering-coefficient
    ]
    ; take the average
    set cc (1 - total / count consumers with [count consumer-link-neighbors > 1])
  ]

  report cc
end

to-report in-neighborhood? [ hood ]
  report ( member? end1 hood and member? end2 hood )
end

to-report find-average-path-length
  let apl 0

  ; calculate all the path-lengths for each node
  find-path-lengths

  let num-connected-pairs sum [length remove 99999 (remove 0 distance-from-other-consumers)] of consumers

  ; In a connected network on N nodes, we should have N(N-1) measurements of distances between pairs.
  ; If there were any "infinity" length paths between nodes, then the network is disconnected.
  ifelse num-connected-pairs != (count consumers * (count consumers - 1)) [
    ; This means the network is not connected, so we report infinity
    set apl 99999
  ][
    set apl (sum [sum distance-from-other-consumers] of consumers) / (num-connected-pairs)
  ]

  report apl
end

to find-path-lengths
  ; reset the distance list
  ask consumers [
    set distance-from-other-consumers []
  ]

  let i 0
  let j 0
  let k 0
  let node1 one-of consumers
  let node2 one-of consumers
  let node-count count consumers
  ; initialize the distance lists
  while [i < node-count] [
    set j 0
    while [ j < node-count ] [
      set node1 consumer i
      set node2 consumer j
      ; zero from a node to itself
      ifelse i = j [
        ask node1 [
          set distance-from-other-consumers lput 0 distance-from-other-consumers
        ]
      ][
        ; 1 from a node to it's neighbor
        ifelse [ consumer-link-neighbor? node1 ] of node2 [
          ask node1 [
            set distance-from-other-consumers lput 1 distance-from-other-consumers
          ]
        ][ ; infinite to everyone else
          ask node1 [
            set distance-from-other-consumers lput 9999 distance-from-other-consumers
          ]
        ]
      ]
      set j j + 1
    ]
    set i i + 1
  ]
  set i 0
  set j 0
  let dummy 0
  while [k < node-count] [
    set i 0
    while [i < node-count] [
      set j 0
      while [j < node-count] [
        ; alternate path length through kth node
        set dummy ( (item k [distance-from-other-consumers] of consumer i) +
                    (item j [distance-from-other-consumers] of consumer k))
        ; is the alternate path shorter?
        if dummy < (item j [distance-from-other-consumers] of consumer i) [
          ask consumer i [
            set distance-from-other-consumers replace-item j distance-from-other-consumers dummy
          ]
        ]
        set j j + 1
      ]
      set i i + 1
    ]
    set k k + 1
  ]

end
@#$#@#$#@
GRAPHICS-WINDOW
233
94
670
532
-1
-1
13.0
1
10
1
1
1
0
0
0
1
-16
16
-16
16
0
0
1
ticks
30.0

SLIDER
8
47
180
80
n-consumers
n-consumers
0
1000
300.0
1
1
NIL
HORIZONTAL

SLIDER
7
163
179
196
random-consumer-links
random-consumer-links
0
20
1.0
1
1
NIL
HORIZONTAL

BUTTON
8
10
71
43
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
79
10
142
43
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
7
235
226
268
influence-threshold
influence-threshold
0
1
0.1
0.01
1
NIL
HORIZONTAL

BUTTON
146
10
209
43
NIL
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SWITCH
296
570
412
603
new-seed?
new-seed?
0
1
-1000

INPUTBOX
419
571
538
631
seed-for-random
1.381912555E9
1
0
Number

TEXTBOX
688
22
746
50
% purchase
11
0.0
1

MONITOR
747
14
831
59
1st dimension
precision (100 * (count consumers with [item 0 purchase = 1]) / n-consumers) 2
17
1
11

MONITOR
838
14
920
59
2nd dimension
precision (100 * (count consumers with [item 1 purchase = 1]) / n-consumers) 2
17
1
11

MONITOR
933
14
1022
59
3rd dimension
precision (100 * (count consumers with [item 2 purchase = 1]) / n-consumers) 2
17
1
11

PLOT
690
229
990
379
purchase
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -13345367 true "" "if ticks != 0 [plot purchase1D]"
"pen-1" 1.0 0 -13840069 true "" "if ticks != 0 [plot purchase2D]"
"pen-2" 1.0 0 -2674135 true "" "if ticks != 0 [plot purchase3D]"
"pen-3" 1.0 0 -7500403 true "" "if ticks != 0 [plot purchase4D]"

INPUTBOX
5
344
70
404
time-limit
51.0
1
0
Number

SLIDER
8
305
180
338
price-premium
price-premium
0
100
5.0
1
1
%
HORIZONTAL

SLIDER
8
129
189
162
proportion-intention-t0
proportion-intention-t0
0
1
0.05
0.01
1
NIL
HORIZONTAL

MONITOR
724
408
801
453
intention1D
intention1D
17
1
11

MONITOR
786
408
863
453
intention2D
intention2D
17
1
11

MONITOR
849
408
926
453
intention3D
intention3D
17
1
11

MONITOR
715
515
783
560
NIL
purchase1D
17
1
11

MONITOR
785
515
864
560
NIL
purchase2D
17
1
11

MONITOR
867
516
946
561
NIL
purchase3D
17
1
11

PLOT
685
77
985
227
intention
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -13345367 true "" "if ticks != 0 [plot intention1D]"
"pen-1" 1.0 0 -10899396 true "" "if ticks != 0 [plot intention2D]"
"pen-2" 1.0 0 -2674135 true "" "if ticks != 0 [plot intention3D]"
"pen-3" 1.0 0 -7500403 true "" "if ticks != 0 [plot intention4D]"

CHOOSER
8
561
146
606
network-type
network-type
"random" "small world"
1

MONITOR
674
567
826
612
clustering-coefficient (cc)
clustering-coefficient
3
1
11

MONITOR
832
568
989
613
average-path-length (apl)
average-path-length
3
1
11

SWITCH
150
570
281
603
random-links?
random-links?
0
1
-1000

CHOOSER
8
81
146
126
n-dimensions
n-dimensions
1 2 3 4
3

SLIDER
7
199
179
232
degree-influence
degree-influence
1
10
2.0
1
1
NIL
HORIZONTAL

SLIDER
8
270
180
303
probability-influence
probability-influence
0
1
0.25
0.05
1
NIL
HORIZONTAL

MONITOR
929
408
1006
453
intention4D
intention4D
17
1
11

MONITOR
1035
15
1124
60
4th dimension
precision (100 * (count consumers with [item 3 purchase = 1]) / n-consumers) 2
17
1
11

MONITOR
949
516
1028
561
NIL
purchase4D
17
1
11

PLOT
1006
78
1254
228
adoption
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -14070903 true "" "if ticks != 0 [plot adoption1D]"
"pen-1" 1.0 0 -12087248 true "" "if ticks != 0 [plot intention2D]"
"pen-2" 1.0 0 -5298144 true "" "if ticks != 0 [plot intention3D]"
"pen-3" 1.0 0 -7500403 true "" "if ticks != 0 [plot intention4D]"

MONITOR
717
463
794
508
NIL
adoption1D
17
1
11

MONITOR
800
463
877
508
NIL
adoption2D
17
1
11

MONITOR
883
464
960
509
NIL
adoption3D
17
1
11

MONITOR
963
463
1040
508
NIL
adoption4D
17
1
11

@#$#@#$#@
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.2.0
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="17 december 2021 experiment 1D, 2D, 3D, 4D" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="51"/>
    <metric>purchase1D</metric>
    <metric>purchase2D</metric>
    <metric>purchase3D</metric>
    <metric>purchase4D</metric>
    <metric>intention1D</metric>
    <metric>intention2D</metric>
    <metric>intention3D</metric>
    <metric>intention4D</metric>
    <metric>adoption1D</metric>
    <metric>adoption2D</metric>
    <metric>adoption3D</metric>
    <metric>adoption4D</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="time-limit">
      <value value="51"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="price-premium">
      <value value="10"/>
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="probability-influence">
      <value value="0.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree-influence">
      <value value="1"/>
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seed-for-random">
      <value value="-1585743939"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;small world&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-consumers">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="random-consumer-links">
      <value value="0"/>
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="random-links?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="influence-threshold">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-dimensions">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-intention-t0">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
